@@ -1,4 +1,4 @@
-import mfasweep
+from mfasweep import mfasweep
 import sys
 
 mfasweep.main(sys.argv)
\ No newline at end of file
